@@ -9,15 +9,15 @@ import psutil
 
 from .types import (
     BlockingProcess,
-    WaitingProcess,
     IOCounter,
     LoadAverage,
     LocalRunningProcess,
     MemoryInfo,
     RunningProcess,
     SortKey,
-    SystemProcess,
     SwapInfo,
+    SystemProcess,
+    WaitingProcess,
 )
 
 
@@ -149,6 +149,8 @@ T = TypeVar("T", RunningProcess, WaitingProcess, BlockingProcess, LocalRunningPr
 def sorted(processes: List[T], *, key: SortKey, reverse: bool = False) -> List[T]:
     """Return processes sorted.
 
+    >>> from ipaddress import IPv4Interface, ip_address
+
     PostgreSQL 13+
     >>> processes = [
     ...     LocalRunningProcess(
@@ -156,13 +158,14 @@ def sorted(processes: List[T], *, key: SortKey, reverse: bool = False) -> List[T
     ...         application_name="pgbench",
     ...         database="pgbench",
     ...         user="postgres",
-    ...         client="local",
+    ...         client=ip_address("127.0.0.2"),
     ...         cpu=0.1,
     ...         mem=0.993_254_939_413_836,
     ...         read=0.1,
     ...         write=0.282_725_318_098_656_75,
     ...         state="idle in transaction",
     ...         query="UPDATE pgbench_accounts SET abalance = abalance + 3062 WHERE aid = 1932841;",
+    ...         encoding="UTF-8",
     ...         duration=0.1,
     ...         wait="ClientRead",
     ...         io_wait=False,
@@ -174,13 +177,14 @@ def sorted(processes: List[T], *, key: SortKey, reverse: bool = False) -> List[T
     ...         application_name="pgbench",
     ...         database="pgbench",
     ...         user="postgres",
-    ...         client="local",
+    ...         client=IPv4Interface("192.0.2.5/24"),
     ...         cpu=0.1,
     ...         mem=0.994_254_939_413_836,
     ...         read=0.1,
     ...         write=0.282_725_318_098_656_75,
     ...         state="idle in transaction",
     ...         query="UPDATE pgbench_accounts SET abalance = abalance + 141 WHERE aid = 7289374;",
+    ...         encoding=None,
     ...         duration=0.1,
     ...         wait="ClientRead",
     ...         io_wait=False,
@@ -192,13 +196,14 @@ def sorted(processes: List[T], *, key: SortKey, reverse: bool = False) -> List[T
     ...         application_name="pgbench",
     ...         database="pgbench",
     ...         user="postgres",
-    ...         client="local",
+    ...         client=ip_address("2001:db8::"),
     ...         cpu=0.2,
     ...         mem=1.024_758_418_061_11,
     ...         read=0.2,
     ...         write=0.113_090_128_201_154_74,
     ...         state="active",
     ...         query="UPDATE pgbench_accounts SET abalance = abalance + 3062 WHERE aid = 1932841;",
+    ...         encoding="UTF-8",
     ...         duration=0.1,
     ...         wait=False,
     ...         io_wait=False,
@@ -227,13 +232,14 @@ def sorted(processes: List[T], *, key: SortKey, reverse: bool = False) -> List[T
     ...         application_name="pgbench",
     ...         database="pgbench",
     ...         user="postgres",
-    ...         client="local",
+    ...         client=ip_address("192.168.1.2"),
     ...         cpu=0.1,
     ...         mem=0.993_254_939_413_836,
     ...         read=0.1,
     ...         write=0.282_725_318_098_656_75,
     ...         state="idle in transaction",
     ...         query="UPDATE pgbench_accounts SET abalance = abalance + 3062 WHERE aid = 1932841;",
+    ...         encoding=None,
     ...         duration=0.1,
     ...         wait="ClientRead",
     ...         io_wait=False,
@@ -245,13 +251,14 @@ def sorted(processes: List[T], *, key: SortKey, reverse: bool = False) -> List[T
     ...         application_name="pgbench",
     ...         database="pgbench",
     ...         user="postgres",
-    ...         client="local",
+    ...         client=ip_address("0000:0000:0000:0000:0000:0abc:0007:0def"),
     ...         cpu=0.1,
     ...         mem=0.994_254_939_413_836,
     ...         read=0.1,
     ...         write=0.282_725_318_098_656_75,
     ...         state="idle in transaction",
     ...         query="UPDATE pgbench_accounts SET abalance = abalance + 141 WHERE aid = 7289374;",
+    ...         encoding="UTF-8",
     ...         duration=0.1,
     ...         wait="ClientRead",
     ...         io_wait=False,
@@ -263,13 +270,14 @@ def sorted(processes: List[T], *, key: SortKey, reverse: bool = False) -> List[T
     ...         application_name="pgbench",
     ...         database="pgbench",
     ...         user="postgres",
-    ...         client="local",
+    ...         client=None,
     ...         cpu=0.2,
     ...         mem=1.024_758_418_061_11,
     ...         read=0.2,
     ...         write=0.113_090_128_201_154_74,
     ...         state="active",
     ...         query="UPDATE pgbench_accounts SET abalance = abalance + 3062 WHERE aid = 1932841;",
+    ...         encoding="latin1",
     ...         duration=0.1,
     ...         wait=False,
     ...         io_wait=False,
