@@ -8,23 +8,23 @@ from io import StringIO
 from typing import Optional
 
 from blessed import Terminal
-from psycopg2.errors import OperationalError
 
 from . import __version__, data, types, ui
+from .config import Configuration, ConfigurationError
+from .pg import OperationalError
 
 
 def configure_logger(debug_file: Optional[str] = None) -> StringIO:
     logger = logging.getLogger("pgactivity")
     logger.setLevel(logging.DEBUG)
 
-    # The steamhandler is used to print hints to the user at exit.
-    # The INFO log level is reserved for this.
+    # The steamhandler is used to print all messages at exit.
     memory_string = StringIO()
     c_handler = logging.StreamHandler(memory_string)
     c_handler.setLevel(logging.INFO)
     c_handler.name = "stream_handler"
 
-    c_format = logging.Formatter("Hint - %(message)s")
+    c_format = logging.Formatter("%(levelname)s - %(message)s")
     c_handler.setFormatter(c_format)
 
     logger.addHandler(c_handler)
@@ -185,6 +185,7 @@ def get_parser() -> ArgumentParser:
             "'host=HOSTNAME port=PORT user=USER dbname=DBNAME'."
         ),
         nargs="?",
+        default="",
         metavar="connection string",
     )
     # -h / --host
@@ -385,6 +386,11 @@ def main() -> None:
     if args.rds:
         args.notempfile = True
 
+    try:
+        cfg = Configuration.lookup()
+    except ConfigurationError as e:
+        parser.error(str(e))
+
     dataobj = data.pg_connect(
         args,
         args.connection_string,
@@ -404,7 +410,7 @@ def main() -> None:
     term = Terminal()
     while True:
         try:
-            ui.main(term, dataobj, host, args)
+            ui.main(term, cfg, dataobj, host, args)
         except OperationalError:
             while True:
                 print(term.clear + term.home, end="")
