@@ -2,49 +2,34 @@ import getpass
 import logging
 import re
 from argparse import Namespace
+from functools import partial
 from typing import Dict, List, Optional
 
 import attr
 import psutil
-import psycopg2
-import psycopg2.extras
-from psycopg2 import sql
-from psycopg2.errors import (
-    FeatureNotSupported,
-    InterfaceError,
-    InvalidPassword,
-    InsufficientPrivilege,
-    OperationalError,
-    ProgrammingError,
-    QueryCanceled,
-)
-from psycopg2.extensions import connection
 
-from . import queries
+from . import pg, queries
+from .pg import Connection, sql
 from .types import (
+    NO_FILTER,
     BlockingProcess,
     FailedQueriesInfo,
     Filters,
-    WaitingProcess,
     Pct,
     RunningProcess,
     ServerInformation,
     TempFileInfo,
-    NO_FILTER,
+    WaitingProcess,
 )
 from .utils import clean_str
 
-
 logger = logging.getLogger("pgactivity")
 
 
-def pg_get_version(pg_conn: connection) -> str:
+def pg_get_version(pg_conn: Connection) -> str:
     """Get PostgreSQL server version."""
-    query = queries.get("get_version")
-    with pg_conn.cursor() as cur:
-        cur.execute(query)
-        ret: Dict[str, str] = cur.fetchone()
-    return ret["pg_version"]
+    ret = pg.fetchone(pg_conn, queries.get("get_version"))
+    return ret["pg_version"]  # type: ignore[no-any-return]
 
 
 def pg_get_short_version(text_version: str) -> str:
@@ -80,9 +65,10 @@ def pg_get_short_version(text_version: str) -> str:
 
 @attr.s(auto_attribs=True, frozen=True, slots=True)
 class Data:
-    pg_conn: connection
+    pg_conn: Connection
     pg_version: str
     pg_num_version: int
+    server_encoding: bytes
     min_duration: float
     filters: Filters
     dsn_parameters: Dict[str, str]
@@ -104,44 +90,41 @@ class Data:
         filters: Filters = NO_FILTER,
     ) -> "Data":
         """Create an instance by connecting to a PostgreSQL server."""
-        pg_conn = psycopg2.connect(
-            dsn=dsn,
+        pg_conn = pg.connect(
+            dsn,
             host=host,
             port=port,
             user=user,
-            database=database,
+            dbname=database,
             password=password,
             application_name="pg_activity",
-            cursor_factory=psycopg2.extras.DictCursor,
         )
-        pg_conn.autocommit = True
-        with pg_conn.cursor() as cur:
-            if hide_queries_in_logs:
-                cur.execute(queries.get("disable_log_min_duration_statement"))
-                if pg_conn.server_version >= 130000:
-                    cur.execute(queries.get("disable_log_min_duration_sample"))
+        if hide_queries_in_logs:
+            pg.execute(pg_conn, queries.get("disable_log_min_duration_statement"))
+            if pg.server_version(pg_conn) >= 130000:
+                pg.execute(pg_conn, queries.get("disable_log_min_duration_sample"))
         pg_version = pg_get_short_version(pg_get_version(pg_conn))
+        server_encoding = pg_conn.info.parameter_status("server_encoding")
+        assert server_encoding is not None
         return cls(
             pg_conn,
             pg_version,
-            pg_conn.server_version,
+            pg.server_version(pg_conn),
+            server_encoding.encode(),
             min_duration=min_duration,
             failed_queries=FailedQueriesInfo(),
             filters=filters,
-            dsn_parameters=pg_conn.info.dsn_parameters,
+            dsn_parameters=pg.connection_parameters(pg_conn),
         )
 
     def try_reconnect(self) -> Optional["Data"]:
         try:
-            pg_conn = psycopg2.connect(
-                cursor_factory=psycopg2.extras.DictCursor, **self.dsn_parameters
-            )
-        except (InterfaceError, OperationalError):
+            pg_conn = pg.connect(**self.dsn_parameters)
+        except (pg.InterfaceError, pg.OperationalError):
             return None
         else:
-            pg_conn.autocommit = True
             return attr.evolve(
-                self, pg_conn=pg_conn, dsn_parameters=pg_conn.info.dsn_parameters
+                self, pg_conn=pg_conn, dsn_parameters=pg.connection_parameters(pg_conn)
             )
 
     def pg_is_local_access(self) -> bool:
@@ -150,19 +133,17 @@ class Data:
         system information for the postmaster process.
         """
         query = queries.get("get_data_directory")
-        with self.pg_conn.cursor() as cur:
-            try:
-                cur.execute(query)
-            except InsufficientPrivilege:
-                logger.info(
-                    "Insufficient privilege to show data_directory. System counters are disabled."
-                )
-                return False
-            ret = cur.fetchone()
+        try:
+            ret = pg.fetchone(self.pg_conn, query)
+        except pg.InsufficientPrivilege:
+            logger.info(
+                "Insufficient privilege to show data_directory. System counters are disabled."
+            )
+            return False
 
         pid_file = f"{ret['data_directory']}/postmaster.pid"
         try:
-            with open(pid_file, "r") as fd:
+            with open(pid_file) as fd:
                 pid = fd.readline().strip()
         except OSError as e:
             logger.info(
@@ -195,10 +176,8 @@ class Data:
         Cancel a backend
         """
         query = queries.get("do_pg_cancel_backend")
-        with self.pg_conn.cursor() as cur:
-            cur.execute(query, {"pid": pid})
-            ret: Dict[str, bool] = cur.fetchone()
-        return ret["is_stopped"]
+        ret = pg.fetchone(self.pg_conn, query, {"pid": pid})
+        return ret["is_stopped"]  # type: ignore[no-any-return]
 
     def pg_terminate_backend(self, pid: int) -> bool:
         """
@@ -208,10 +187,8 @@ class Data:
             query = queries.get("do_pg_terminate_backend")
         else:
             query = queries.get("do_pg_cancel_backend")
-        with self.pg_conn.cursor() as cur:
-            cur.execute(query, {"pid": pid})
-            ret: Dict[str, bool] = cur.fetchone()
-        return ret["is_stopped"]
+        ret = pg.fetchone(self.pg_conn, query, {"pid": pid})
+        return ret["is_stopped"]  # type: ignore[no-any-return]
 
     def pg_get_temporary_file(self) -> Optional[TempFileInfo]:
         """
@@ -229,35 +206,33 @@ class Data:
         else:
             query = queries.get("get_temporary_files_oldest")
 
-        with self.pg_conn.cursor() as cur:
-            try:
-                cur.execute(queries.get("set_statement_timeout"), {"timeout": "400ms"})
-                cur.execute(query)
-                ret = cur.fetchone()
-            except InsufficientPrivilege:
-                # superuser or pg_read_server_files are required (Issue #278)
-                cur.execute(queries.get("reset_statement_timeout"))
-                self.failed_queries.temp_file_query_failed = True
-                logger.info(
-                    "Insufficient privilege to fetch the tempfile data. "
-                    "The feature was disabled. Please use --no-tempfiles or a platform specific setting (eg. --rds)."
-                )
+        try:
+            pg.execute(
+                self.pg_conn,
+                sql.SQL("SET statement_timeout TO {}").format(sql.Literal("400ms")),
+            )
+            return pg.fetchone(self.pg_conn, query, mkrow=TempFileInfo)
+        except pg.InsufficientPrivilege:
+            # superuser or pg_read_server_files are required (Issue #278)
+            self.failed_queries.temp_file_query_failed = True
+            logger.info(
+                "Insufficient privilege to fetch the tempfile data. "
+                "The feature was disabled. Please use --no-tempfiles or a platform specific setting (eg. --rds)."
+            )
 
-                return None
-            except QueryCanceled:
-                # if an excessive amount of tempfile exists, the query could be very long
-                # to avoid such a case we set a statement_timeout shorter than the lowest
-                # refresh rate. This could end up spamming the PostgreSQL logs.
-                self.failed_queries.temp_file_query_failed = True
-                cur.execute(queries.get("reset_statement_timeout"))
-                logger.info(
-                    "The tempfile query ended in a timeout. "
-                    "The feature was disabled. Check the temporary files on the server."
-                )
-                return None
-            cur.execute(queries.get("reset_statement_timeout"))
-
-        return TempFileInfo(**ret)
+            return None
+        except pg.QueryCanceled:
+            # if an excessive amount of tempfile exists, the query could be very long
+            # to avoid such a case we set a statement_timeout shorter than the lowest
+            # refresh rate. This could end up spamming the PostgreSQL logs.
+            self.failed_queries.temp_file_query_failed = True
+            logger.info(
+                "The tempfile query ended in a timeout. "
+                "The feature was disabled. Check the temporary files on the server."
+            )
+            return None
+        finally:
+            pg.execute(self.pg_conn, queries.get("reset_statement_timeout"))
 
     def pg_get_wal_senders(self) -> Optional[int]:
         """
@@ -267,11 +242,7 @@ class Data:
             query = queries.get("get_wal_senders_post_090100")
         else:
             return None
-
-        with self.pg_conn.cursor() as cur:
-            cur.execute(query)
-            ret = cur.fetchone()
-
+        ret = pg.fetchone(self.pg_conn, query)
         return int(ret["wal_senders"])
 
     def pg_get_wal_receivers(self) -> Optional[int]:
@@ -289,10 +260,8 @@ class Data:
             return None
 
         try:
-            with self.pg_conn.cursor() as cur:
-                cur.execute(query)
-                ret = cur.fetchone()
-        except FeatureNotSupported:
+            ret = pg.fetchone(self.pg_conn, query)
+        except pg.FeatureNotSupported:
             # Not implemented on Aurora (Issue #301)
             self.failed_queries.wal_receivers_query_failed = True
             logger.info(
@@ -311,13 +280,15 @@ class Data:
             query = queries.get("get_replication_slots_post_140000")
         else:
             return None
-
-        with self.pg_conn.cursor() as cur:
-            cur.execute(query)
-            ret = cur.fetchone()
-
+        ret = pg.fetchone(self.pg_conn, query)
         return int(ret["replication_slots"])
 
+    @property
+    def dbname_filter(self) -> sql.Composable:
+        if self.filters.dbname:
+            return sql.Literal(self.filters.dbname)
+        return sql.NULL
+
     def pg_get_server_information(
         self,
         prev_server_info: Optional[ServerInformation] = None,
@@ -349,24 +320,24 @@ class Data:
         else:
             query = queries.get("get_server_info_oldest")
 
-        with self.pg_conn.cursor() as cur:
-            try:
-                cur.execute(
-                    query,
-                    {
-                        "dbname_filter": self.filters.dbname,
-                        "skip_db_size": skip_db_size,
-                        "prev_total_size": prev_total_size,
-                        "using_rds": using_rds,
-                    },
-                )
-            except InsufficientPrivilege:
-                logger.info(
-                    "Privileges might be insufficient to connect to a database. "
-                    "Try to use a --filter, the --no-db-size option or a platform specific setting (eg. --rds)"
-                )
-                raise
-            ret = cur.fetchone()
+        qs = sql.SQL(query).format(dbname_filter=self.dbname_filter)
+        try:
+            ret = pg.fetchone(
+                self.pg_conn,
+                qs,
+                {
+                    "dbname_filter": self.filters.dbname,
+                    "skip_db_size": skip_db_size,
+                    "prev_total_size": prev_total_size,
+                    "using_rds": using_rds,
+                },
+            )
+        except pg.InsufficientPrivilege:
+            logger.info(
+                "Privileges might be insufficient to connect to a database. "
+                "Try to use a --filter, the --no-db-size option or a platform specific setting (eg. --rds)"
+            )
+            raise
 
         temporary_file_info: Optional[TempFileInfo] = None
         if not skip_tempfile:
@@ -432,19 +403,22 @@ class Data:
             qs = queries.get("get_pg_activity_oldest")
 
         duration_column = self.get_duration_column(duration_mode)
-        query = sql.SQL(qs).format(duration_column=sql.Identifier(duration_column))
+        query = sql.SQL(qs).format(
+            dbname_filter=self.dbname_filter,
+            duration_column=sql.Identifier(duration_column),
+            min_duration=sql.Literal(self.min_duration),
+        )
 
-        with self.pg_conn.cursor() as cur:
-            cur.execute(
-                query,
-                {
-                    "min_duration": self.min_duration,
-                    "dbname_filter": self.filters.dbname,
-                },
-            )
-            ret = cur.fetchall()
-
-        return [RunningProcess(**row) for row in ret]
+        return pg.fetchall(
+            self.pg_conn,
+            query,
+            {
+                "min_duration": self.min_duration,
+                "dbname_filter": self.filters.dbname,
+            },
+            mkrow=partial(RunningProcess.from_bytes, self.server_encoding),
+            text_as_bytes=True,
+        )
 
     def pg_get_waiting(self, duration_mode: int = 1) -> List[WaitingProcess]:
         """
@@ -456,18 +430,22 @@ class Data:
             qs = queries.get("get_waiting_oldest")
 
         duration_column = self.get_duration_column(duration_mode)
-        query = sql.SQL(qs).format(duration_column=sql.Identifier(duration_column))
+        query = sql.SQL(qs).format(
+            dbname_filter=self.dbname_filter,
+            duration_column=sql.Identifier(duration_column),
+            min_duration=sql.Literal(self.min_duration),
+        )
 
-        with self.pg_conn.cursor() as cur:
-            cur.execute(
-                query,
-                {
-                    "min_duration": self.min_duration,
-                    "dbname_filter": self.filters.dbname,
-                },
-            )
-            ret = cur.fetchall()
-        return [WaitingProcess(**row) for row in ret]
+        return pg.fetchall(
+            self.pg_conn,
+            query,
+            {
+                "min_duration": self.min_duration,
+                "dbname_filter": self.filters.dbname,
+            },
+            mkrow=partial(WaitingProcess.from_bytes, self.server_encoding),
+            text_as_bytes=True,
+        )
 
     def pg_get_blocking(self, duration_mode: int = 1) -> List[BlockingProcess]:
         """
@@ -481,27 +459,29 @@ class Data:
             qs = queries.get("get_blocking_oldest")
 
         duration_column = self.get_duration_column(duration_mode)
-        query = sql.SQL(qs).format(duration_column=sql.Identifier(duration_column))
+        query = sql.SQL(qs).format(
+            dbname_filter=self.dbname_filter,
+            duration_column=sql.Identifier(duration_column),
+            min_duration=sql.Literal(self.min_duration),
+        )
 
-        with self.pg_conn.cursor() as cur:
-            cur.execute(
-                query,
-                {
-                    "min_duration": self.min_duration,
-                    "dbname_filter": self.filters.dbname,
-                },
-            )
-            ret = cur.fetchall()
-        return [BlockingProcess(**row) for row in ret]
+        return pg.fetchall(
+            self.pg_conn,
+            query,
+            {
+                "min_duration": self.min_duration,
+                "dbname_filter": self.filters.dbname,
+            },
+            mkrow=partial(BlockingProcess.from_bytes, self.server_encoding),
+            text_as_bytes=True,
+        )
 
     def pg_is_local(self) -> bool:
         """
-        Is pg_activity connected localy ?
+        Is pg_activity connected locally?
         """
         query = queries.get("get_pga_inet_addresses")
-        with self.pg_conn.cursor() as cur:
-            cur.execute(query)
-            ret = cur.fetchone()
+        ret = pg.fetchone(self.pg_conn, query)
         if ret["inet_server_addr"] == ret["inet_client_addr"]:
             return True
         return False
@@ -546,10 +526,10 @@ def pg_connect(
                 filters=filters,
                 hide_queries_in_logs=options.hide_queries_in_logs,
             )
-        except OperationalError as err:
+        except pg.OperationalError as err:
             errmsg = str(err).strip()
             if nb_try < 1 and (
-                isinstance(err, InvalidPassword)
+                isinstance(err, pg.InvalidPassword)
                 or errmsg.startswith("FATAL:  password authentication failed for user")
                 or errmsg == "fe_sendauth: no password supplied"
             ):
@@ -559,7 +539,7 @@ def pg_connect(
                 raise SystemExit("pg_activity: FATAL: %s" % clean_str(msg))
             else:
                 raise Exception("Could not connect to PostgreSQL")
-        except ProgrammingError as err:
+        except pg.ProgrammingError as err:
             errmsg = str(err).strip()
             if errmsg.startswith("invalid dsn"):
                 raise SystemExit(
