@@ -1,6 +1,7 @@
 import enum
 import functools
 from datetime import timedelta
+from ipaddress import IPv4Address, IPv6Address
 from typing import (
     Any,
     Callable,
@@ -11,18 +12,20 @@ from typing import (
     Mapping,
     MutableSet,
     Optional,
-    overload,
     Sequence,
     Tuple,
+    Type,
     TypeVar,
     Union,
+    overload,
 )
 
 import attr
 import psutil
 from attr import validators
 
-from . import compat, colors, utils
+from . import colors, compat, pg, utils
+from .config import Configuration, Flag
 
 
 class Pct(float):
@@ -52,87 +55,6 @@ def enum_next(e: E) -> E:
     return e.__class__((e.value % max(e.__class__)) + 1)
 
 
-@enum.unique
-class Flag(enum.IntFlag):
-    """Column flag."""
-
-    DATABASE = 1
-    APPNAME = 2
-    CLIENT = 4
-    USER = 8
-    CPU = 16
-    MEM = 32
-    READ = 64
-    WRITE = 128
-    TIME = 256
-    WAIT = 512
-    RELATION = 1024
-    TYPE = 2048
-    MODE = 4096
-    IOWAIT = 8192
-    PID = 16384
-
-    @classmethod
-    def all(cls) -> "Flag":
-        return cls(sum(cls))
-
-    @classmethod
-    def from_options(
-        cls,
-        *,
-        is_local: bool,
-        noappname: bool,
-        noclient: bool,
-        nocpu: bool,
-        nodb: bool,
-        nomem: bool,
-        nopid: bool,
-        noread: bool,
-        notime: bool,
-        nouser: bool,
-        nowait: bool,
-        nowrite: bool,
-        **kwargs: Any,
-    ) -> "Flag":
-        """Build a Flag value from command line options."""
-        flag = cls.all()
-        if nodb:
-            flag ^= cls.DATABASE
-        if nouser:
-            flag ^= cls.USER
-        if nocpu:
-            flag ^= cls.CPU
-        if noclient:
-            flag ^= cls.CLIENT
-        if nomem:
-            flag ^= cls.MEM
-        if noread:
-            flag ^= cls.READ
-        if nowrite:
-            flag ^= cls.WRITE
-        if notime:
-            flag ^= cls.TIME
-        if nowait:
-            flag ^= cls.WAIT
-        if noappname:
-            flag ^= cls.APPNAME
-        if nopid:
-            flag ^= cls.PID
-
-        # Remove some if no running against local pg server.
-        if not is_local and (flag & cls.CPU):
-            flag ^= cls.CPU
-        if not is_local and (flag & cls.MEM):
-            flag ^= cls.MEM
-        if not is_local and (flag & cls.READ):
-            flag ^= cls.READ
-        if not is_local and (flag & cls.WRITE):
-            flag ^= cls.WRITE
-        if not is_local and (flag & cls.IOWAIT):
-            flag ^= cls.IOWAIT
-        return flag
-
-
 @attr.s(auto_attribs=True, frozen=True, slots=True)
 class Filters:
     dbname: Optional[str] = None
@@ -192,6 +114,15 @@ class DurationMode(enum.IntEnum):
 _color_key_marker = f"{id(object())}"
 
 
+def if_none(default: str) -> Callable[[Any], str]:
+    def transform(value: Any) -> str:
+        if value is None:
+            return default
+        return str(value)
+
+    return transform
+
+
 @attr.s(auto_attribs=True, frozen=True, slots=True)
 class Column:
     """A column in stats table.
@@ -230,9 +161,7 @@ class Column:
     justify: str = attr.ib(
         "left", validator=validators.in_(["left", "center", "right"])
     )
-    transform: Callable[[Any], str] = attr.ib(
-        default=lambda v: str(v) if v is not None else "", repr=False
-    )
+    transform: Callable[[Any], str] = attr.ib(default=if_none(""), repr=False)
     color_key: Union[str, Callable[[Any], str]] = attr.ib(
         default=_color_key_marker, repr=False
     )
@@ -299,6 +228,7 @@ class UI:
     @classmethod
     def make(
         cls,
+        config: Optional[Configuration] = None,
         flag: Flag = Flag.all(),
         *,
         max_db_length: int = 16,
@@ -308,6 +238,14 @@ class UI:
         possible_columns: Dict[str, Column] = {}
 
         def add_column(key: str, name: str, **kwargs: Any) -> None:
+            if config is not None:
+                try:
+                    cfg = config[name.lower()]
+                except KeyError:
+                    pass
+                else:
+                    if cfg.width is not None:
+                        kwargs["min_width"] = kwargs["max_width"] = cfg.width
             assert key not in possible_columns, f"duplicated key {key}"
             possible_columns[key] = Column(key=key, name=name, **kwargs)
 
@@ -326,6 +264,7 @@ class UI:
                 min_width=16,
                 max_width=16,
                 justify="right",
+                transform=if_none("local"),
             )
         if Flag.CPU & flag:
             add_column(
@@ -903,13 +842,35 @@ class BaseProcess:
     application_name: str
     database: Optional[str]
     user: str
-    client: str
+    client: Union[None, IPv4Address, IPv6Address]
     duration: Optional[float]
     state: str
     query: Optional[str]
+    encoding: Optional[str]
     query_leader_pid: Optional[int]
     is_parallel_worker: bool
 
+    _P = TypeVar("_P", bound="BaseProcess")
+
+    @classmethod
+    def from_bytes(
+        cls: Type[_P],
+        server_encoding: bytes,
+        *,
+        encoding: Optional[Union[str, bytes]],
+        **kwargs: Any,
+    ) -> _P:
+        if encoding is None:
+            enc = server_encoding
+        elif isinstance(encoding, bytes):  # psycopg2
+            enc, encoding = encoding, encoding.decode()
+        elif isinstance(encoding, str):
+            enc = encoding.encode()
+        for name, value in kwargs.items():
+            if isinstance(value, bytes):
+                kwargs[name] = pg.decode(value, enc, errors="replace")
+        return cls(encoding=encoding, **kwargs)
+
 
 @attr.s(auto_attribs=True, frozen=True, slots=True)
 class RunningProcess(BaseProcess):
