@@ -1,19 +1,35 @@
 import functools
 import re
 from datetime import datetime, timedelta
-from typing import Any, IO, Iterable, List, Mapping, Optional, Tuple, Union
+from typing import IO, Any, Iterable, List, Mapping, Optional, Tuple, Union
 
 import attr
 import humanize
 
-
 naturalsize = functools.partial(humanize.naturalsize, gnu=True, format="%.2f")
-naturaltimedelta = functools.partial(
-    humanize.precisedelta,
-    minimum_unit="minutes",
-    format="%.0f",
-    suppress=["months", "years"],
-)
+try:
+    precisedelta = humanize.precisedelta
+except AttributeError:  # humanize < 2.6
+
+    def naturaltimedelta(d: timedelta) -> str:
+        """Render a timedelta with seconds truncated.
+
+        >>> d = timedelta(days=5, seconds=15182, microseconds=129198)
+        >>> naturaltimedelta(d)
+        '5 days, 4:13:00'
+        >>> str(d)
+        '5 days, 4:13:02.129198'
+        """
+        d = timedelta(days=d.days, seconds=d.seconds // 60 * 60)
+        return str(d)
+
+else:
+    naturaltimedelta = functools.partial(
+        humanize.precisedelta,
+        minimum_unit="minutes",
+        format="%.0f",
+        suppress=["months", "years"],
+    )
 
 
 @attr.s(auto_attribs=True, frozen=True, slots=True)
@@ -137,9 +153,9 @@ def format_duration(duration: Optional[float]) -> Tuple[str, str]:
             color = "time_red"
         duration_d = timedelta(seconds=float(duration))
         mic = "%.6d" % duration_d.microseconds
-        ctime = "%s:%s.%s" % (
-            str((duration_d.seconds // 60)).zfill(2),
-            str((duration_d.seconds % 60)).zfill(2),
+        ctime = "{}:{}.{}".format(
+            str(duration_d.seconds // 60).zfill(2),
+            str(duration_d.seconds % 60).zfill(2),
             mic[:2],
         )
     else:
