@@ -2,33 +2,26 @@ import functools
 import inspect
 import itertools
 from textwrap import TextWrapper, dedent
-from typing import (
-    Any,
-    Callable,
-    Iterable,
-    Iterator,
-    List,
-    Optional,
-    Tuple,
-    Sequence,
-)
+from typing import Any, Callable, Iterable, Iterator, List, Optional, Sequence, Tuple
 
 from blessed import Terminal
 
+from . import colors, utils
+from .activities import sorted as sorted_processes
 from .compat import link
+from .keys import BINDINGS, EXIT_KEY
+from .keys import HELP as HELP_KEY
 from .keys import (
-    BINDINGS,
-    EXIT_KEY,
-    HELP as HELP_KEY,
     KEYS_BY_QUERYMODE,
-    Key,
     MODES,
     PAUSE_KEY,
     PROCESS_CANCEL,
     PROCESS_KILL,
     PROCESS_PIN,
+    Key,
 )
 from .types import (
+    UI,
     ActivityStats,
     Column,
     Host,
@@ -37,10 +30,7 @@ from .types import (
     SelectableProcesses,
     ServerInformation,
     SystemInfo,
-    UI,
 )
-from . import colors, utils
-from .activities import sorted as sorted_processes
 
 
 class line_counter:
@@ -146,8 +136,7 @@ def help(term: Terminal, version: str, is_local: bool) -> Iterable[str]:
             yield f"{term.bright_cyan}{key_name.rjust(10)}{term.normal}: {key.description}"
 
     footer = "Press any key to exit."
-    for line in intro.splitlines():
-        yield line
+    yield from intro.splitlines()
     yield ""
 
     bindings = BINDINGS
@@ -199,7 +188,7 @@ def header(
         return f"{term.bold_green(hbytes)} - {term.bold_green(counts)}"
 
     def render_columns(
-        columns: Sequence[List[str]], *, delimiter: str
+        columns: Sequence[List[str]], *, delimiter: str = f"{term.blue(',')} "
     ) -> Iterator[str]:
         column_widths = [
             max(len(column_row) for column_row in column) for column in columns
@@ -248,7 +237,7 @@ def header(
             [f"{render(total_size)} dbs size - {render(size_ev)} growth"],
             [f"{render(si.cache_hit_ratio_last_snap)} cache hit ratio"],
         ]
-        yield from render_columns(columns, delimiter=f" {term.bold_blue('⋅')} ")
+        yield from render_columns(columns)
 
         columns = [
             [f"  Sessions: {render(si.total)}/{render(si.max_connections)} total"],
@@ -258,7 +247,7 @@ def header(
             [f"{render(si.idle_in_transaction_aborted)} idle in txn abrt"],
             [f"{render(si.waiting)} waiting"],
         ]
-        yield from render_columns(columns, delimiter=f" {term.bold_blue('⋅')} ")
+        yield from render_columns(columns)
 
         if si.temporary_file is not None:
             temp_files = si.temporary_file.temp_files
@@ -275,7 +264,7 @@ def header(
             [f"{render(temp_files)} temp files"],
             [f"{render(temp_size)} temp size"],
         ]
-        yield from render_columns(columns, delimiter=f" {term.bold_blue('⋅')} ")
+        yield from render_columns(columns)
     if ui.show_worker_info_in_header:
         columns = [
             [
@@ -288,7 +277,7 @@ def header(
                 f"{render(si.parallel_workers)}/{render(si.max_parallel_workers)} parallel workers"
             ],
         ]
-        yield from render_columns(columns, delimiter=f" {term.bold_blue('⋅')} ")
+        yield from render_columns(columns)
 
         columns = [
             [
@@ -300,7 +289,7 @@ def header(
                 f"{render(si.replication_slots)}/{render(si.max_replication_slots)} repl. slots"
             ],
         ]
-        yield from render_columns(columns, delimiter=f" {term.bold_blue('⋅')} ")
+        yield from render_columns(columns)
 
     # System information, only available in "local" mode.
     if system_info is not None and ui.show_system_info_in_header:
@@ -316,7 +305,7 @@ def header(
             [f"{render(used)} ({render(system_info.memory.pct_used)}) used"],
             [f"{render(bc)} ({render(system_info.memory.pct_bc)}) buff+cached"],
         ]
-        yield from render_columns(system_columns, delimiter=f" {term.bold_blue('⋅')} ")
+        yield from render_columns(system_columns)
 
         used, free, total = (
             utils.naturalsize(system_info.swap.used),
@@ -328,7 +317,7 @@ def header(
             [f"{render(free)} ({render(system_info.swap.pct_free)}) free"],
             [f"{render(used)} ({render(system_info.swap.pct_used)}) used"],
         ]
-        yield from render_columns(system_columns, delimiter=f" {term.bold_blue('⋅')} ")
+        yield from render_columns(system_columns)
 
         iops = f"{system_info.max_iops}/s"
         system_columns = [
@@ -336,7 +325,7 @@ def header(
             [f"{render(system_info.io_read)} read"],
             [f"{render(system_info.io_write)} write"],
         ]
-        yield from render_columns(system_columns, delimiter=f" {term.bold_blue('⋅')} ")
+        yield from render_columns(system_columns)
 
         load = system_info.load
         system_columns = [
@@ -344,7 +333,7 @@ def header(
                 f"  Load average: {render(load.avg1)} {render(load.avg5)} {render(load.avg15)}"
             ],
         ]
-        yield from render_columns(system_columns, delimiter=f" {term.bold_blue('⋅')} ")
+        yield from render_columns(system_columns)
 
 
 @limit
@@ -382,7 +371,8 @@ def columns_header(term: Terminal, ui: UI) -> Iterator[str]:
 def get_indent(ui: UI) -> str:
     """Return indentation for Query column.
 
-    >>> from pgactivity.types import Flag, UI
+    >>> from pgactivity.config import Flag
+    >>> from pgactivity.types import UI
     >>> ui = UI.make(flag=Flag.CPU)
     >>> get_indent(ui)
     '                         '
@@ -452,7 +442,6 @@ def processes_rows(
     focused, pinned = processes.focused, processes.pinned
 
     for process in display_processes:
-
         if process.pid == focused:
             color_type = "cursor"
         elif process.pid in pinned:
@@ -479,8 +468,7 @@ def processes_rows(
 
             cell(query_value, ui.column("query"))
 
-        for line in (" ".join(text) + term.normal).splitlines():
-            yield line
+        yield from (" ".join(text) + term.normal).splitlines()
 
 
 def footer_message(term: Terminal, message: str, width: Optional[int] = None) -> None:
